#
# slpk04.rb
#
# $Id$
#

require "numru/dcl"

include NumRu
include Math


#-- data ---
x = [-7.5, 7.5, 7.5, -7.5, -7.5]
y = [-7.5,-7.5, 7.5,  7.5, -7.5]

#-- graph ---
iws = (ARGV[0] || (puts ' WORKSTATION ID (I)  ? ;'; DCL::sgpwsn; gets)).to_i
DCL::sgopn iws

xmaxf = 26.0
ymaxf = 18.5
DCL::slform(xmaxf, ymaxf)        # <-- Ūѻ礭
DCL::slrat(xmaxf, ymaxf)

DCL::sglset('LFULL', true)
DCL::sgfrm

DCL::sgswnd(-xmaxf/2.0, xmaxf/2.0, -ymaxf/2.0, ymaxf/2.0)
DCL::sgstrf
DCL::sgplu(x, y)
DCL::sgtxzu(0.0, 0.0, "15cm #{DCL::usgi(194)} 15cm", 0.05, 0, 0, 3)

DCL::sgcls

